@@ -3,7 +3,7 @@
 use std::mem;
 
 use Result;
-use band::{Band, Value, ValueExt};
+use tape::{Tape, Value, ValueExt};
 
 /// A glyph identifier.
 pub type GlyphID = u16;
@@ -15,30 +15,30 @@ pub type OffsetSize = u8;
 pub type StringID = u16;
 
 macro_rules! fill(
-    ($band:ident, $count:expr, $buffer:ident) => (
-        if try!(::std::io::Read::read($band, &mut $buffer)) != $count {
+    ($tape:ident, $count:expr, $buffer:ident) => (
+        if try!(::std::io::Read::read($tape, &mut $buffer)) != $count {
             return raise!("failed to read as much as needed");
         }
     );
 );
 
 macro_rules! read(
-    ($band:ident, $size:expr) => (unsafe {
+    ($tape:ident, $size:expr) => (unsafe {
         let mut buffer: [u8; $size] = mem::uninitialized();
-        fill!($band, $size, buffer);
+        fill!($tape, $size, buffer);
         mem::transmute(buffer)
     });
 );
 
 macro_rules! implement {
     ($name:ident, 1) => (impl Value for $name {
-        fn read<T: Band>(band: &mut T) -> Result<Self> {
-            Ok(read!(band, 1))
+        fn read<T: Tape>(tape: &mut T) -> Result<Self> {
+            Ok(read!(tape, 1))
         }
     });
     ($name:ident, $size:expr) => (impl Value for $name {
-        fn read<T: Band>(band: &mut T) -> Result<Self> {
-            Ok($name::from_be(read!(band, $size)))
+        fn read<T: Tape>(tape: &mut T) -> Result<Self> {
+            Ok($name::from_be(read!(tape, $size)))
         }
     });
 }
@@ -48,10 +48,10 @@ implement!(u16, 2);
 implement!(u32, 4);
 
 impl ValueExt<usize> for Vec<u8> {
-    fn read<T: Band>(band: &mut T, count: usize) -> Result<Self> {
+    fn read<T: Tape>(tape: &mut T, count: usize) -> Result<Self> {
         let mut values = Vec::with_capacity(count);
         unsafe { values.set_len(count) };
-        fill!(band, count, values);
+        fill!(tape, count, values);
         Ok(values)
     }
 }
