@@ -18,8 +18,8 @@ fn header() {
 
     assert_eq!(table.major, 1);
     assert_eq!(table.minor, 0);
-    assert_eq!(table.hdrSize, 4);
-    assert_eq!(table.offSize, 2);
+    assert_eq!(table.header_size, 4);
+    assert_eq!(table.offset_size, 2);
 }
 
 #[test]
